@@ -14,66 +14,41 @@
 #ifndef LLVM_CONFIG_H
 #define LLVM_CONFIG_H
 
-/* Installation directory for binary executables */
-/* #undef LLVM_BINDIR */
-
-/* Time at which LLVM was configured */
-/* #undef LLVM_CONFIGTIME */
-
-/* Installation directory for data files */
-/* #undef LLVM_DATADIR */
+/* Define if we link Polly to the tools */
+/* #undef LINK_POLLY_INTO_TOOLS */
 
 /* Target triple LLVM will generate code for by default */
-#define LLVM_DEFAULT_TARGET_TRIPLE "amd64-unknown-openbsd6.0"
-
-/* Installation directory for documentation */
-/* #undef LLVM_DOCSDIR */
-
-/* Define if LLVM is built with asserts and checks that change the layout of
-   client-visible data structures.  */
-/* #undef LLVM_ENABLE_ABI_BREAKING_CHECKS */
+#define LLVM_DEFAULT_TARGET_TRIPLE "mips64-unknown-openbsd6.1"
 
 /* Define if threads enabled */
 #define LLVM_ENABLE_THREADS 1
 
-/* Installation directory for config files */
-/* #undef LLVM_ETCDIR */
-
 /* Has gcc/MSVC atomic intrinsics */
 #define LLVM_HAS_ATOMICS 1
 
 /* Host triple LLVM will be executed on */
-#define LLVM_HOST_TRIPLE "amd64-unknown-openbsd6.0"
-
-/* Installation directory for include files */
-/* #undef LLVM_INCLUDEDIR */
-
-/* Installation directory for .info files */
-/* #undef LLVM_INFODIR */
-
-/* Installation directory for man pages */
-/* #undef LLVM_MANDIR */
+#define LLVM_HOST_TRIPLE "mips64-unknown-openbsd6.1"
 
 /* LLVM architecture name for the native architecture, if available */
-#define LLVM_NATIVE_ARCH X86
+#define LLVM_NATIVE_ARCH Mips
 
 /* LLVM name for the native AsmParser init function, if available */
-#define LLVM_NATIVE_ASMPARSER LLVMInitializeX86AsmParser
+#define LLVM_NATIVE_ASMPARSER LLVMInitializeMipsAsmParser
 
 /* LLVM name for the native AsmPrinter init function, if available */
-#define LLVM_NATIVE_ASMPRINTER LLVMInitializeX86AsmPrinter
+#define LLVM_NATIVE_ASMPRINTER LLVMInitializeMipsAsmPrinter
 
 /* LLVM name for the native Disassembler init function, if available */
-#define LLVM_NATIVE_DISASSEMBLER LLVMInitializeX86Disassembler
+#define LLVM_NATIVE_DISASSEMBLER LLVMInitializeMipsDisassembler
 
 /* LLVM name for the native Target init function, if available */
-#define LLVM_NATIVE_TARGET LLVMInitializeX86Target
+#define LLVM_NATIVE_TARGET LLVMInitializeMipsTarget
 
 /* LLVM name for the native TargetInfo init function, if available */
-#define LLVM_NATIVE_TARGETINFO LLVMInitializeX86TargetInfo
+#define LLVM_NATIVE_TARGETINFO LLVMInitializeMipsTargetInfo
 
 /* LLVM name for the native target MC init function, if available */
-#define LLVM_NATIVE_TARGETMC LLVMInitializeX86TargetMC
+#define LLVM_NATIVE_TARGETMC LLVMInitializeMipsTargetMC
 
 /* Define if this is Unixish platform */
 #define LLVM_ON_UNIX 1
@@ -85,24 +60,21 @@
 #define LLVM_PREFIX "/usr/local"
 
 /* Define if we have the Intel JIT API runtime support library */
-/* #undef LLVM_USE_INTEL_JITEVENTS */
+#define LLVM_USE_INTEL_JITEVENTS 0
 
 /* Define if we have the oprofile JIT-support library */
-/* #undef LLVM_USE_OPROFILE */
+#define LLVM_USE_OPROFILE 0
 
 /* Major version of the LLVM API */
-#define LLVM_VERSION_MAJOR 3
+#define LLVM_VERSION_MAJOR 4
 
 /* Minor version of the LLVM API */
-#define LLVM_VERSION_MINOR 8
+#define LLVM_VERSION_MINOR 0
 
 /* Patch version of the LLVM API */
 #define LLVM_VERSION_PATCH 0
 
 /* LLVM version string */
-#define LLVM_VERSION_STRING "3.8.0"
-
-/* Define if we link Polly to the tools */
-/* #undef LINK_POLLY_INTO_TOOLS */
+#define LLVM_VERSION_STRING "4.0.0"
 
 #endif
